/*
    Video maid
    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __SIZE_H__
#define __SIZE_H__


#include "vmaid.h"


typedef struct SizeDialog_Tag {
	gboolean ratio;			/* TRUE:Ψݻʤ,FALSE:Ψݻ */
	gint view,width,height,def_width,def_height;
} SizeDialog;


/*	ե졼ॵ
	      view,
	     width,
	    height,⤵
	 def_width,ǥեȤ
	def_height,ǥեȤι⤵												*/
void size_set_scale(const gint view,gint *width,gint *height,
								const gint def_width,const gint def_height);


gboolean size_dialog(SizeDialog *size);


#endif
